---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE] Please add your feature request title"
labels: enhancement
assignees: ''

---

<!-- We follow Design thinking principles to bring the new feature request to life. Please read through [Design thinking](https://www.interaction-design.org/literature/article/5-stages-in-the-design-thinking-process) principles if you are not familiar. -->

<!-- This is the [Board](https://github.com/orgs/Nike-Inc/projects/4) your feature request would go through, so keep in mind that there would be more back and forth on this. If you are very clear with all phases, please describe them here for faster development. -->

## Is your feature request related to a problem? Please describe.
<!-- A clear and concise description of what the problem is. Ex. I'm always frustrated when [...] -->
...

## Describe the solution you'd like
<!-- A clear and concise description of what you want to happen. -->
...

## Describe alternatives you've considered
<!-- A clear and concise description of any alternative solutions or features you've considered. -->
...

## Additional context
<!-- Add any other context or screenshots about the feature request here. -->
...
